Learn R Programming

Morpho (version 2.0.2)

asymPermute: Assess differences in amount and direction of asymmetric variation

Description

Assess differences in amount and direction of asymmetric variation

Usage

asymPermute(x, groups, rounds = 1000, which = 1:2)

Arguments

x
object of class symproc result from calling procSym with pairedLM specified
groups
factors determining grouping.
rounds
number of permutations
which
in case the factor levels are >2 this determins which factorlevels to use

Value

  • distdifference between vector lengths of group means
  • angleangle between vectors of group specific asymmetric deviation
  • meansactual group averages
  • p.distp-value obtained by comparing the actual distance to randomly acquired distances
  • p.anglep-value obtained by comparing the actual angle to randomly acquired angles
  • permudistvector containing differences between random group means' vector lenghts
  • permuanglevector containing angles between random group means' vectors