cExtract: extract information about fixed landmarks, curves and patches from and atlas
generated by "landmark"
Description
After exporting the pts file of the atlas from "landmark"
and importing it into R via "read.pts" cExtract gets
information which rows of the landmark datasets belong to
curves or patches.
Usage
cExtract(pts.file)
Arguments
pts.file
either a character naming the path to a
pts.file or the name of an object imported via read.pts.
Value
returns a list containing the vectors with the indices of
matrix rows belonging to the in "landmark" defined curves,
patches and fix landmarks and a matrix containing landmark
coordinates.