Usage
procSym(dataarray, scale = TRUE, reflect = TRUE, CSinit = TRUE,
orp = TRUE, tol = 1e-05, pairedLM = NULL, sizeshape = FALSE,
use.lm = NULL, center.part = FALSE, distfun = c("angle", "riemann"),
SMvector = NULL, outlines = NULL, deselect = FALSE, recursive = TRUE,
iterations = 0, initproc = FALSE)Arguments
dataarray
Input k x m x n real array, where k is
the number of points, m is the number of dimensions, and
n is the sample size.
scale
logical: indicating if scaling is requested
reflect
logical: allow reflections.
CSinit
logical: if TRUE, all configurations are
initially scaled to Unit Centroid Size.
orp
logical: if TRUE, an orthogonal projection at
the meanshape into tangent space is performed.
tol
numeric: Threshold for convergence in the
sliding process
pairedLM
A X x 2 matrix containing the indices
(rownumbers) of the paired LM. E.g. the left column
contains the lefthand landmarks, while the right side
contains the corresponding right hand landmarks.
sizeshape
Logical: if TRUE, a log transformed
variable of Centroid Size will be added to the shapedata
as first variable before performing the PCA.
use.lm
vector of integers to define a subset of
landmarks to be used for Procrustes registration.
center.part
Logical: if TRUE, the data
superimposed by the subset defined by use.lm will be
centered according to the centroid of the complete
configuration. Otherwise orp will be set to FALSE to
avoid erroneous projection into tangent space.
distfun
character: "riemann" requests a Riemannian
distance for calculating distances to mean, while "angle"
uses an approximation by calculating the angle between
rotated shapes on the unit sphere.
SMvector
A vector containing the landmarks on the
curve(s) that are allowed to slide
outlines
A vector (or if threre are several
curves) a list of vectors (containing the rowindices) of
the (Semi-)landmarks forming the curve(s) in the
successive position on the curve - including the
beginning and end points, that are not allowed to slide.
deselect
Logical: if TRUE, the SMvector is
interpreted as those landmarks, that are not allowed to
slide.
recursive
Logical: if TRUE, during the iterations
of the sliding process, the outcome of the previous
iteration will be used. Otherwise the original
configuration will be used in all iterations.
iterations
integer: select manually how many
iterations will be performed during the sliding process
(usefull, when there is very slow convergence). 0 means
iteration until convergence.
initproc
Logical: indicating if the first
Relaxation step is performed against the mean of an
initial Procrustes superimposition. Symmetric
configurations will be relaxed against a perfectly
symmetrical mean.