projRead: Project points onto the closest point on a mesh
Description
project points onto a given surface and return projected
points and normals.Usage
projRead(lm, mesh, readnormals = TRUE, smooth = TRUE, sign = TRUE, ...)
Arguments
lm
m x 3 matrix containing 3D coordinates.
mesh
character: specify path to mesh file.
readnormals
logical: return normals of projected
points.
smooth
logical: rerturn smoothed normals.
sign
logical: request signed distances.
...
additional arguments currently not used.
Value
- if readnormals = FALSE, a m x 3 matrix containing projected
points is returned, otherwise a list, where
- vb3 x
m matrix containing projected points
- normals3 x m
matrix containing normals
- qualityvector
containing distances
References
Detection of inside/outside uses the algorithm proposed in:Baerentzen, Jakob Andreas. & Aanaes, H., 2002. Generating
Signed Distance Fields From Triangle Meshes. Informatics
and Mathematical Modelling.
Examples
Run this codedata(nose)
repro <- projRead(shortnose.lm,shortnose.mesh)
Run the code above in your browser using DataLab