reference matrix used to estimate rotation
parameters
tarmat
target matrix used to estimate rotation
parameters
scale
logical: requests scaling to minimize sums
of squared distances
reflection
logical: if TRUE, reflections are
allowed.
weights
vector of length k, containing weights for
each landmark.
centerweight
logical: if weights are defined and
centerweigths=TRUE, the matrix will be centered according
to these weights instead of the barycenter.
Value
returns rotated X.
Details
A matrix is rotated by rotation parameters determined by
two different matrices. This is usefull, if the rotation
parameters are to be estimated by a subset of landmark
coordinates.