Rdocumentation
powered by
Learn R Programming
Morpho (version 2.0.2)
asymPermute: Assess differences in amount and direction of asymmetric variation
Description
Assess differences in amount and direction of asymmetric variation
Usage
asymPermute(x, groups, rounds = 1000, which = 1:2)
Arguments
x
object of class symproc result from calling
procSym
with
pairedLM
specified
groups
factors determining grouping.
rounds
number of permutations
which
in case the factor levels are >2 this determins which factorlevels to use
Value
dist
difference between vector lengths of group means
angle
angle between vectors of group specific asymmetric deviation
means
actual group averages
p.dist
p-value obtained by comparing the actual distance to randomly acquired distances
p.angle
p-value obtained by comparing the actual angle to randomly acquired angles
permudist
vector containing differences between random group means' vector lenghts
permuangle
vector containing angles between random group means' vectors